# libpythonpypiade
Módulo para exemplificar construção de projetos Python no curso PyTools

Nesse curso é ensinado como contribuir com projetos de código aberto

link do curso [Python Pro](https://pythonpro.com.br/)

[![Build Status](https://app.travis-ci.com/AdemilsonMelo/libpythonpypiade.svg?branch=main)](https://app.travis-ci.com/AdemilsonMelo/libpythonpypiade)
[![Updates](https://pyup.io/repos/github/AdemilsonMelo/libpythonpypiade/shield.svg)](https://pyup.io/repos/github/AdemilsonMelo/libpythonpypiade/)
[![Python 3](https://pyup.io/repos/github/AdemilsonMelo/libpythonpypiade/python-3-shield.svg)](https://pyup.io/repos/github/AdemilsonMelo/libpythonpypiade/)

Suportada versão 3 de Python

Para instalar:
```console
py -3 -m venv .venv
source .venv\Scripts\activate
pip install -r requirements-dev.txt
```

Para conferir qualidade do código:
```console
flake8
```

Tópicos a serem abordados:
1. Git
2. Virtualenv
3. Pip 
